@@ -902,7 +902,7 @@ class ZonalStatsBase(object):
         self._w = value
 
     def check_empty(self):
-        """"""
+        """ """
         isempty = np.repeat(False, len(self.w))
         for i, weights in enumerate(self.w):
             if np.sum(weights) == 0 or np.isnan(np.sum(weights)):
@@ -1261,7 +1261,7 @@ def get_clip_mask(coords, clippoly, srs=None):
     zd = ZonalDataPoint(coords.reshape(-1, coords.shape[-1]), clip, srs=srs)
 
     # Subsetting in order to use only precipitating profiles
-    src_mask = np.zeros(coords.shape[0:-1], dtype=np.bool)
+    src_mask = np.zeros(coords.shape[0:-1], dtype=np.bool_)
 
     try:
         obj = ZonalStatsPoint(zd)
